@@ -40,6 +40,6 @@ inner_join.data.table <- function(x, ..., .expr = FALSE) {
         lazy_ans
     }
     else {
-        end_expr.ExprBuilder(lazy_ans, .parent_env = rlang::caller_env())
+        try_delegate("inner_join", end_expr.ExprBuilder(lazy_ans, .parent_env = rlang::caller_env()))
     }
 }
